from distutils.core import setup, Extension
from distutils.command.build import build
import subprocess
import os
import sys

datadir = '/usr/share'
defsdir = datadir+'/pygtk/2.0/defs'
includedir = '/usr/include'

def get_includes(package_name):
    """Used to get include dirs from pkg-config"""

    args = ["pkg-config", "--cflags", package_name]
    proc = subprocess.Popen(
        args,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE
    )
    
    cmdresult = proc.stdout
    error = proc.stderr
    
    if cmdresult:
        result = cmdresult.read()
        includes = [x[2:] for x in result.split()] # Strip the -I
        return includes
        
    return []

def gen_auto_file(filename, subproc_args):
    proc = subprocess.Popen(
        subproc_args,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE
    )
    cmdresult = proc.stdout
    error = proc.stderr
    #Print disabled to avoid problems with scratchbox
    #print error.read()
    if cmdresult:
        new_file = open(filename, 'w')
        new_file.write(cmdresult.read())
        #print "###############3File %s generated ###############" % filename
	new_file.close()

class PyMamanBuild(build):
    def run(self):
        """Create the temporary files used to compile the conic module:
        -conic.c
        -conic-types.h.in
        -conic-types.c.in"""
        # Generate enum/flags run-time information
        MAMAN_TYPE_FILES = ['maman-file.h'
	]
        
	gen_auto_file('maman-types.h.in', ['/bin/sh', './gen-enum-h']+MAMAN_TYPE_FILES)
	gen_auto_file('maman-types.c.in', ['/bin/sh', './gen-enum-c']+MAMAN_TYPE_FILES)

        # Creation of ".c" files, using pygtk-codegen-2.0
        override_filename = 'maman.override'
        defs_filename = 'maman.defs'

        parameter = [
            '--register', defsdir+'/gdk.defs',
            '--register', defsdir+'/gtk-types.defs',
            '--override', override_filename,
            '--prefix', 'pymaman',
	    defs_filename,
	] 
	gen_auto_file('maman.c', ['/bin/sh', 'pygtk-codegen-2.0']+parameter)

        build.run(self)
        

compile_args = [
        '-Os',
        '-DXTHREADS',
        '-DXUSE_MTSAFE_API',
#        '-ansi',
#        '-pedantic',
#        '-Wno-long-long',
#        '-g',
#        '-rdynamic',
]

# Using get_includes plus pygtk headers
maman = Extension('maman',
    sources = [
        'maman.c',
        'mamanmodule.c',
        'maman-types.c',
    ],
    libraries = [
        'dbus-1',
                'dbus-glib-1',
                'glib-2.0',
                'gobject-2.0',
    ],
    include_dirs=get_includes("gobject-2.0")+get_includes("dbus-glib-1")+['/usr/include/pygtk-2.0'],
    extra_compile_args=compile_args,
    extra_objects=['maman-file.o']
)

setup(
    name = 'maman',
    version = '0.1',
    description = 'Python bindings for the dummy maman package',
    author = 'Lauro Moura Maranhao Neto',
    author_email = 'lauromoura@gmail.com',
    url = 'http://www.maemo.org',
    ext_modules = [maman],
    cmdclass={'build': PyMamanBuild}
)
